==> openshift-model-whereabouts-5.11.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/OverlappingRangeIPReservationSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class OverlappingRangeIPReservationSpecFluentImpl<A extends io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservationSpecFluent<A>{
  public OverlappingRangeIPReservationSpecFluentImpl() {
  }
  public OverlappingRangeIPReservationSpecFluentImpl(io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservationSpec instance) {
    this.withContainerid(instance.getContainerid()); 
    this.withPodref(instance.getPodref()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String containerid;
  private java.lang.String podref;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getContainerid() {
    return this.containerid;
  }
  public A withContainerid(java.lang.String containerid) {
    this.containerid=containerid; return (A) this;
  }
  public java.lang.Boolean hasContainerid() {
    return this.containerid != null;
  }
  
  /**
   * Method is deprecated. use withContainerid instead.
   */
  @java.lang.Deprecated
  public A withNewContainerid(java.lang.String arg0) {
    return (A)withContainerid(new String(arg0));
  }
  public java.lang.String getPodref() {
    return this.podref;
  }
  public A withPodref(java.lang.String podref) {
    this.podref=podref; return (A) this;
  }
  public java.lang.Boolean hasPodref() {
    return this.podref != null;
  }
  
  /**
   * Method is deprecated. use withPodref instead.
   */
  @java.lang.Deprecated
  public A withNewPodref(java.lang.String arg0) {
    return (A)withPodref(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OverlappingRangeIPReservationSpecFluentImpl that = (OverlappingRangeIPReservationSpecFluentImpl) o;
    if (containerid != null ? !containerid.equals(that.containerid) :that.containerid != null) return false;
    if (podref != null ? !podref.equals(that.podref) :that.podref != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerid,  podref,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-whereabouts-5.12.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/OverlappingRangeIPReservationSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class OverlappingRangeIPReservationSpecFluentImpl<A extends io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservationSpecFluent<A>{
  public OverlappingRangeIPReservationSpecFluentImpl() {
  }
  public OverlappingRangeIPReservationSpecFluentImpl(io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservationSpec instance) {
    this.withContainerid(instance.getContainerid()); 
    this.withPodref(instance.getPodref()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String containerid;
  private java.lang.String podref;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getContainerid() {
    return this.containerid;
  }
  public A withContainerid(java.lang.String containerid) {
    this.containerid=containerid; return (A) this;
  }
  public java.lang.Boolean hasContainerid() {
    return this.containerid != null;
  }
  
  /**
   * Method is deprecated. use withContainerid instead.
   */
  @java.lang.Deprecated
  public A withNewContainerid(java.lang.String arg0) {
    return (A)withContainerid(new String(arg0));
  }
  public java.lang.String getPodref() {
    return this.podref;
  }
  public A withPodref(java.lang.String podref) {
    this.podref=podref; return (A) this;
  }
  public java.lang.Boolean hasPodref() {
    return this.podref != null;
  }
  
  /**
   * Method is deprecated. use withPodref instead.
   */
  @java.lang.Deprecated
  public A withNewPodref(java.lang.String arg0) {
    return (A)withPodref(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OverlappingRangeIPReservationSpecFluentImpl that = (OverlappingRangeIPReservationSpecFluentImpl) o;
    if (containerid != null ? !containerid.equals(that.containerid) :that.containerid != null) return false;
    if (podref != null ? !podref.equals(that.podref) :that.podref != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerid,  podref,  additionalProperties,  super.hashCode());
  }
  
}
